
package org.virtualbox_7_2.jaxws;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for GraphicsFeature.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="GraphicsFeature">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     &lt;enumeration value="None"/>
 *     &lt;enumeration value="Acceleration3D"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 * 
 */
@XmlType(name = "GraphicsFeature")
@XmlEnum
public enum GraphicsFeature {

    @XmlEnumValue("None")
    NONE("None"),
    @XmlEnumValue("Acceleration3D")
    ACCELERATION_3_D("Acceleration3D");
    private final String value;

    GraphicsFeature(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static GraphicsFeature fromValue(String v) {
        for (GraphicsFeature c: GraphicsFeature.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}
